%define shortVersion %(echo %{version} | cut -d. -f1,2)

%bcond_with bootstrap

Name: cmake
Summary: Cross-platform, open-source make system
Version: 2.8.2
Release: %mkrel 1
License: BSD
Group: Development/Other
Epoch: 1
Url: http://www.cmake.org/HTML/index.html
Source0: http://www.cmake.org/files/v%{shortVersion}/%name-%{version}.tar.gz
Source1: cmake.macros
# fix ftlk detection
Patch1: cmake-fltk-path.patch
Patch2: cmake-2.8.2-xz-support.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: perl
BuildRequires: ncurses-devel
BuildRequires: libcurl-devel
BuildRequires: idn-devel
BuildRequires: zlib-devel
BuildRequires: xz
BuildRequires: expat-devel
%if ! %with bootstrap
BuildRequires: qt4-devel >= 4.4.0
%endif
BuildRequires: gcc-gfortran
%if %mdkversion > 200900
Conflicts: vim-common < 7.2.079-4
%endif
Requires: rpm-manbo-setup >= 2-10

%description
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.
CMake generates native makefiles and workspaces that can be
used in the compiler environment of your choice. CMake is quite
sophisticated: it is possible to support complex environments
requiring system configuration, pre-processor generation, code
generation, and template instantiation.

%files
%defattr(-,root,root)
%_bindir/cmake
%_bindir/ccmake
%_bindir/ctest
%_bindir/cpack
%_mandir/man1/*
%_datadir/%{name}
%_sysconfdir/emacs/site-start.d/%{name}.el
%_sysconfdir/rpm/macros.d/*
%_datadir/emacs/site-lisp/cmake-mode.el
%if %mdkversion > 200900
%_datadir/vim/*/*
%endif
%doc CMakeLogo.gif Example mydocs/*

#-----------------------------------------------------------------------------

%if ! %with bootstrap
%package -n %{name}-qtgui
Summary:    Qt GUI Dialog for CMake - the Cross-platform, open-source make system
Group:      Development/Other
Requires:   %name

%description -n %{name}-qtgui
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.

This is the Qt GUI.

%files -n %{name}-qtgui
%_bindir/cmake-gui
%_datadir/applications/CMake.desktop
%_datadir/mime/packages/cmakecache.xml
%_datadir/pixmaps/CMakeSetup32.png
%endif

#-----------------------------------------------------------------------------

%prep
%setup -q -n %name-%{version}
%patch1
%patch2 -p1 -b .xz

# Don't try to automagically find files in /usr/X11R6
# But also don't change a prefix if it is not /usr
perl -pi -e 's@^\s+/usr/X11R6/.*\n@@' Modules/*.cmake

%ifarch %arm
# bootstrap test is taking ages on arm
sed -i -e 's!SET(CMAKE_LONG_TEST_TIMEOUT 1500)!SET(CMAKE_LONG_TEST_TIMEOUT 7200)!g' Tests/CMakeLists.txt
%endif

%build
mkdir -p build
cd build
%setup_compile_flags
../configure \
    --system-libs \
    --parallel=%_smp_mflags \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --mandir=/share/man \
    --docdir=/share/doc/%{name} \
%if ! %with bootstrap
    --qt-gui
%endif

%make

%install
rm -rf %buildroot
pushd build
%makeinstall_std
popd

# cmake mode for emacs
install -m644 Docs/cmake-mode.el -D %buildroot%_datadir/emacs/site-lisp/cmake-mode.el
install -d %buildroot%_sysconfdir/emacs/site-start.d
cat <<EOF >%buildroot%_sysconfdir/emacs/site-start.d/%{name}.el
(setq load-path (cons (expand-file-name "/dir/with/cmake-mode") load-path))
(require 'cmake-mode)
(setq auto-mode-alist
      (append '(("CMakeLists\\\\.txt\\\\'" . cmake-mode)
                ("\\\\.cmake\\\\'" . cmake-mode))
              auto-mode-alist))
EOF

%if %mdkversion > 200900
# cmake mode for vim
install -m644 Docs/cmake-syntax.vim -D %buildroot%_datadir/vim/syntax/cmake.vim
install -m644 Docs/cmake-indent.vim -D %buildroot%_datadir/vim/indent/cmake.vim
%endif

# RPM macros
install -m644 %SOURCE1 -D %buildroot%_sysconfdir/rpm/macros.d/cmake.macros

# %doc wipes out files in doc dir, fixed in cooker svn for rpm package, though
# not submitted yet, so we'll just work around this by moving it for now..
rm -rf mydocs
mv %buildroot%_datadir/doc/%{name} mydocs

%check
unset DISPLAY
cd build
bin/ctest -V

%clean
rm -rf %buildroot


%changelog
* Tue Jul 27 2010 Funda Wang <fwang@mandriva.org> 1:2.8.2-1mdv2011.0
+ Revision: 560902
- New version 2.8.2

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 1:2.8.1-1mdv2010.1
+ Revision: 525975
- fix xz patch
- update file list
- New version 2.8.1

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Add a warning about the use of -DCMAKE_MODULE_LINKER_FLAGS for kde qt apps

* Sat Nov 14 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-9mdv2010.1
+ Revision: 465942
- 2.8.0 final

* Fri Nov 13 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-8mdv2010.1
+ Revision: 465799
- new version 2.8.0 rc7

* Wed Nov 11 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-7mdv2010.1
+ Revision: 464481
- 2.8 rc6

* Wed Nov 04 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-6mdv2010.1
+ Revision: 460415
- 2.8 rc5
- New version 2.8.0 rc4

* Sat Oct 10 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-5mdv2010.0
+ Revision: 456524
- 2.8 rc3
- vtk patch not neede since cmake search for vtk's own cmake module

* Wed Oct 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8.0-4mdv2010.0
+ Revision: 455780
- rebuild for new curl SSL backend

* Tue Oct 06 2009 Thierry Vignaud <tv@mandriva.org> 1:2.8.0-3mdv2010.0
+ Revision: 454727
- do not package huge ChangeLog

* Sat Oct 03 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-2mdv2010.0
+ Revision: 452812
- do not check license of xz patch
- add BSD license to xz patch (aquired by peroyvind)
- 2.8 rc2

* Mon Sep 28 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.8.0-1mdv2010.0
+ Revision: 450565
- New code doesn't have requires on libxml-c-rpc
- New upstream version release candidate 1

* Fri Sep 25 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.4-7mdv2010.0
+ Revision: 449016
- Make release as default in cmake macros

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 1:2.6.4-4mdv2010.0
+ Revision: 448833
- increase timeout for long test on arm, tests 89 (bootstrap) is
  taking a lot of time (from Arnaud Patard)
- introduce a bootstrap option to break loop build dep,
  cups->htmldoc->fltk->cmake->qt4->cups (from Arnaud Patard)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - * fix broken macro messing with rpath making it unable to active due to
      redefinition, rpath should be OFF (skipped) by default, but also possible
      to override to enable

* Fri May 01 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.4-3mdv2010.0
+ Revision: 369195
- Build with debug

* Thu Apr 30 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.4-2mdv2010.0
+ Revision: 369165
- Add back cooker debug by default

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - New version

* Tue Mar 31 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-4mdv2009.1
+ Revision: 363092
- Debug switch is only alocated on cmake macros now. To enable debug a
  _enable_debug 1 should be passed to package build
- Use same debug conditional style like kde4

* Fri Feb 27 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-2mdv2009.1
+ Revision: 345543
- Small adjust for old distros

* Mon Feb 23 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.3-1mdv2009.1
+ Revision: 344267
- Update to final version

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add gcc-gfortran to buildrequires since it's required by the test suite
    - make cmake datadir unversioned so that other software may install their .cmake
      files to a standard location where they can be made use of

* Thu Feb 19 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-0.RC13.2mdv2009.1
+ Revision: 342768
- People insist that VERBOSE should be on by default. Guess what ? Will not
  happens.

* Thu Feb 12 2009 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC13.1mdv2009.1
+ Revision: 339709
- 2.6.3 RC 13

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - make verbosive build into a macro which can be override, thus making it optional
    - fix typo

* Tue Jan 27 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-0.RC8.3mdv2009.1
+ Revision: 334143
- People are going too far and not letting anyone happy with such decisions.

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - revert previous patch as the info message printed next to the progress bar
      actually is colored..
    - make progress indicator colored to make it more clear, especially with several
      build jobs in parallel (P3, hopefully makes Colin happy?:)
    - don't blindly modify all files for lib64, cmake files are lib64 aware already
    - make cmake.macros more in sync with fedora to make it easier to maintain
    - drop chrpath buildrequires since it's chrpath isn't even used during build
    - make build verbose
    - build cmake in a separate build dir rather than in the source dir
    - fix docs so that we don't ship more than we want and don't breaking short
      circuiting
    - minor spec cosmetics..
    - don't add rpaths to linked libraries
    - add -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON to %%cmake macro to print build output by
      default

* Thu Jan 22 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:2.6.3-0.RC8.2mdv2009.1
+ Revision: 332397
- add support for tar.xz (TXZ) generator and cmake file for liblzma (P2)

  + Helio Chissini de Castro <helio@mandriva.com>
    - Provide vim files now, instead of obsolete one from vim package.
    - Use system libs instead of internal sources
    - Added ultiporc compilation since bootstrap

* Wed Jan 14 2009 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC8.1mdv2009.1
+ Revision: 329494
- make test in check section
- 2.6.3 RC 8
- define CMAKE_MODULE_LINKER_FLAGS so that linking modules won't fail

* Fri Dec 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC5.3mdv2009.1
+ Revision: 313576
- BR idn

* Fri Dec 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC5.2mdv2009.1
+ Revision: 313567
- use compile flags

* Thu Dec 11 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.3-0.RC5.1mdv2009.1
+ Revision: 312871
- New version 2.6.3 RC 5
- Add cmake Qtgui

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.2-1mdv2009.1
+ Revision: 292807
- New version 2.6.2

* Thu Aug 21 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.1-1mdv2009.0
+ Revision: 274618
- New upstream version

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1:2.6.0-4mdv2009.0
+ Revision: 264356
- rebuild early 2009.0 package (before pixel changes)

* Fri Jun 06 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-3mdv2009.0
+ Revision: 216531
- Implement new cmake macro to accomplish first part of bug https://qa.mandriva.com/show_bug.cgi?id=41284 ( new flags )

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 1:2.6.0-2mdv2009.0
+ Revision: 213502
- Don't try to automagically find files in /usr/X11R6.
  But also don't change a prefix if it is not /usr.

  + Funda Wang <fwang@mandriva.org>
    - fix url

* Wed May 07 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-1mdv2009.0
+ Revision: 202676
- Upstream 2.6.0 final release

* Wed Apr 30 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-0.1.rc9mdv2009.0
+ Revision: 199613
- Start to use new cmake 2.6 in release candidate 9. Better do early adopt now.

* Fri Feb 08 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.4.8-1mdv2008.1
+ Revision: 164160
- Reverting cmake for stable 2.4.8. KDE 4 assume > 2.4.5 and going to devel version is leading to some unexpected path bad behavior.
- Patches from expat and wx was backported

* Wed Feb 06 2008 Helio Chissini de Castro <helio@mandriva.com> 2.5.0-0.20080106.1mdv2008.1
+ Revision: 163028
- Update to more recent CVS snapshot
- Removed already applied upstream expat and wx patches

* Wed Jan 30 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.5.0-0.20071024.3mdv2008.1
+ Revision: 160292
- Fix expat detection (bug CMake#6062).

* Tue Jan 08 2008 Olivier Blin <oblin@mandriva.com> 2.5.0-0.20071024.2mdv2008.1
+ Revision: 146562
- fix wx-config output being flattened
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Oct 24 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 2.5.0-0.20071024.1mdv2008.1
+ Revision: 101840
- Update to cvs snapshot (because kde4 needs it)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%_datadir/man by %%_mandir!

* Thu Jul 19 2007 Funda Wang <fwang@mandriva.org> 2.4.7-1mdv2008.0
+ Revision: 53410
- New version

  + Helio Chissini de Castro <helio@mandriva.com>
    - Add rpm macros for cmake. Thanks to Anssi Hannula for point this ones.


* Tue Jan 23 2007 Gustavo De Nardin <gustavodn@mandriva.com> 2.4.6-2mdv2007.0
+ Revision: 112566
- don't double package some documentation files
- install emacs mode

* Fri Jan 12 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-1mdv2007.1
+ Revision: 107768
- 2.4.6

* Tue Jan 09 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-0.rc2.1mdv2007.1
+ Revision: 106621
- 2.4.6-rc2

* Tue Dec 05 2006 Laurent Montel <lmontel@mandriva.com> 2.4.5-1mdv2007.1
+ Revision: 90681
- 2.4.5

* Tue Nov 21 2006 Laurent Montel <lmontel@mandriva.com> 2.4.4-1mdv2007.1
+ Revision: 85881
- 2.4.4

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - fix fltk detection (patch 1)

* Wed Aug 02 2006 Laurent Montel <lmontel@mandriva.com> 2.4.3-2mdv2007.0
+ Revision: 42884
- New release 2.4.3 (2006/08/01)
- 2.4.3
- 2.4.2

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - update release tag
    - fix vtk 5.0 detection

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added the current source
    - New Cmake 2.4.1 beta. Required for current KDE 4 development
    - Added cmake on subversion. Gaetan, current maintainer was already notified and now, since kde 4 move development pro cmake and Laurent, me and Boiko will need cmake up to date

* Sat Mar 25 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.2mdk
- lib -> lib64 on x86_64 - the fix in cmake is not enough

* Tue Mar 21 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.1mdk
- 2.3.4 (snapshot 20060321)

* Wed Mar 15 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060315.2mdk
- build requires

* Wed Mar 15 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.4-0.20060315.1mdk
- 2.3.4 (snapshot 20060315)

* Sun Mar 12 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060312.1mdk
- 2.3.4 (snapshot 20060312)

* Sun Feb 12 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.3
- 2.3.3 (snapshot 20060210)

* Fri Feb 10 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.2
- 2.3.2 version (snapshot 20060209)

* Fri Feb 03 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.3-3mdk
- fix kde search path

* Sun Jan 22 2006 Laurent MONTEL <lmontel@mandriva.com> 2.2.3-2mdk
- Fix spec file. I don't understand how a 2.2.2 spec file was integrate into 2.2.3 package (nobody couldn't rebuild it)

* Fri Nov 04 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.2-1mdk
- New release 2.2.2

* Thu Oct 20 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.1-1mdk
- New release 2.2.1

* Tue Jul 19 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.0-1mdk
- 2.2.0
- make it more rpmbuildupdatable
- buildrequires ncurses-devel
- list files in bindir to be sure that ccmake is built

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-3mdk
- also fix X11 lib path on x86_64

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-2mdk
- fix lib path to make ccmake compile on x86_64. It should also help
  to find lib with this arch

* Wed Apr 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-1mdk
- New release 2.0.6
- use mkrel

* Fri Mar 11 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.5-2mdk
- fix some lint
- add examples in docs

* Tue Nov 23 2004 Gaetan LEHMANN <gaetan.lehmann@jouy.inra.fr> 2.0.5-1mdk
- 2.0.5

* Wed Jun 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.6.7-2mdk
- Rebuild

